<xsl:stylesheet 
  version="1.0" 
  exclude-result-prefixes="x d xsl msxsl cmswrt"
  xmlns:x="http://www.w3.org/2001/XMLSchema" 
  xmlns:d="http://schemas.microsoft.com/sharepoint/dsp" 
  xmlns:cmswrt="http://schemas.microsoft.com/WebParts/v3/Publishing/runtime"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:msxsl="urn:schemas-microsoft-com:xslt"
  xmlns:ddwrt="http://schemas.microsoft.com/WebParts/v2/DataView/runtime">    
 
	<xsl:template name="removeMarkup">
		<xsl:param name="string" />
		<xsl:choose>
			<xsl:when test="contains($string, '&lt;')">
				<xsl:variable name="nextString">
					<xsl:call-template name="removeMarkup">
						<xsl:with-param name="string" select="substring-after($string, '&gt;')" />
					</xsl:call-template>
				</xsl:variable>
				<xsl:value-of select="concat(substring-before($string, '&lt;'), $nextString)" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$string" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>	

<!-- item styles for mobcolab -->

	<xsl:template name="SliderStyle" match="Row[@Style='SliderStyle']" mode="itemstyle">

		<xsl:variable name="SafeLinkUrl">
			<xsl:call-template name="OuterTemplate.GetSafeLink">
				<xsl:with-param name="UrlColumnName" select="'LinkUrl'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="SafeImageUrl">
			<xsl:call-template name="OuterTemplate.GetSafeStaticUrl">
				<xsl:with-param name="UrlColumnName" select="'Picture'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="DisplayTitle">
			<xsl:call-template name="OuterTemplate.GetTitle">
				<xsl:with-param name="Title" select="@Title"/>
				<xsl:with-param name="UrlColumnName" select="'LinkUrl'"/>
			</xsl:call-template>
		</xsl:variable>
        
		<xsl:variable name="LinkTarget">
			<xsl:if test="@OpenInNewWindow = 'True'" >_blank</xsl:if>
		</xsl:variable>
        
		<xsl:variable name="Article">
			<xsl:call-template name="removeMarkup">
				<xsl:with-param name="string" select="@Article"/>
			</xsl:call-template>
		</xsl:variable>

		<xsl:variable name="Created">
			<xsl:value-of select="ddwrt:FormatDateTime(string(@Date) ,1033 ,'MM.dd.yyyy')" />
		</xsl:variable>

		<xsl:variable name="back">
			<xsl:value-of select="concat('/site',$SafeLinkUrl,'&amp;source=/site/Pages/Home.aspx')" />
		</xsl:variable>


		<xsl:variable name="tableOpen">&lt;table border=0&gt;&lt;tr&gt;&lt;td valign=&quot;top&quot;&gt;&lt;ul id=&quot;slider&quot;&gt;</xsl:variable>

		<xsl:variable name="tableClose">&lt;/ul&gt;&lt;/td&gt;&lt;/tr&gt;&lt;/table&gt;</xsl:variable>



		<xsl:if test="count(preceding-sibling::*)=0">
			<xsl:value-of select="$tableOpen" disable-output-escaping="yes" />		
		</xsl:if>


		<li>

		<table cellpadding="10" border="0" style="background: #a9cfe5;background: -webkit-gradient(linear, left top, left bottom, from(#a9cfe5), to(#eff7fb));background: -moz-linear-gradient(top,  #a9cfe5,  #eff7fb);filter:  progid:DXImageTransform.Microsoft.gradient(startColorstr='#a9cfe5', endColorstr='#eff7fb');">
			<tr>
			<td width="220px" valign="top">

			<xsl:choose>
				<xsl:when test="string-length($SafeImageUrl) = 0">
					<a href="{$back}" target="{$LinkTarget}" style="float:left; padding:3px;">
						<img class="image" src="http://siteURL/site/PublishingImages/site-chrome/default-image.png" alt="{@ImageUrlAltText}" width="200" height="180" />
					</a>
				</xsl:when>
				<xsl:otherwise>
				<a href="{$back}" target="{$LinkTarget}" style="float:left; padding:3px;">
					<img class="image" src="{$SafeImageUrl}" alt="{@ImageUrlAltText}" width="200" height="180" />
				</a>
				</xsl:otherwise>
			</xsl:choose>

			</td><td width="260px" valign="top">

			<a href="{$back}" target="{$LinkTarget}" title="{@LinkToolTip}" style="color:#000000;font-size:18px;font-weight:bold;display:block;">
				<xsl:value-of select="$DisplayTitle"/>
			</a>
			<xsl:value-of select="substring($Article, 0, 300)" disable-output-escaping="yes" />...
			<br /><br />
			<a href="{$back}" target="{$LinkTarget}" title="{@LinkToolTip}" style="display:block;">Learn More</a>

			</td>
			</tr>
		</table>

		</li>

		<xsl:if test="count(following-sibling::*)=0">
			<xsl:value-of select="$tableClose" disable-output-escaping="yes" />	
		</xsl:if>

	</xsl:template>

	
<!-- end item styles for mobcolab -->

</xsl:stylesheet>